@@ -14,7 +14,7 @@ from .event import Event
 
 
 class SweepLine:
-    __slots__ = ('current_x', '_tree')
+    __slots__ = 'current_x', '_tree'
 
     def __init__(self, *events: Event,
                  current_x: Optional[Coordinate] = None) -> None:
@@ -55,7 +55,7 @@ class SweepLine:
 
 
 class SweepLineKey:
-    __slots__ = ('sweep_line', 'event')
+    __slots__ = 'sweep_line', 'event'
 
     def __init__(self, sweep_line: SweepLine, event: Event) -> None:
         self.sweep_line = sweep_line
