@@ -6,4 +6,5 @@ Coordinate = Real
 Point = Tuple[Coordinate, Coordinate]
 Segment = Tuple[Point, Point]
 Contour = List[Point]
-Polygon = Tuple[Contour, List[Contour]]
+Multicontour = List[Contour]
+Polygon = Tuple[Contour, Multicontour]
